==> haskell-unexceptionalio-0.5.1-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unexceptionalio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unexceptionalio
version:              0.5.1
visibility:           public
id:                   unexceptionalio-0.5.1-6IxKBTb3CJ2L1m1AvesDi3
key:                  unexceptionalio-0.5.1-6IxKBTb3CJ2L1m1AvesDi3
license:              LicenseRef-OtherLicense
copyright:            © 2013-2018 Stephen Paul Weber
maintainer:           Stephen Paul Weber <singpolyma@singpolyma.net>
author:               Stephen Paul Weber <singpolyma@singpolyma.net>
stability:            experimental
homepage:             https://github.com/singpolyma/unexceptionalio
synopsis:             IO without any non-error, synchronous exceptions
description:
    When you'\''ve caught all the exceptions that can be handled safely,
    this is what you'\''re left with.

    It is intended that you use qualified imports with this library.

    > import UnexceptionalIO (UIO)
    > import qualified UnexceptionalIO as UIO

    You may also wish to investigate unexceptionalio-trans if you like
    monad transformers.

    Blog post: http://sngpl.ma/p4uT0

category:             Control
abi:                  a0fbc3f7719ddee0fd81acccbead8006
exposed:              True
exposed-modules:      UnexceptionalIO
import-dirs:          /usr/lib/ghc-8.10.5/site-local/unexceptionalio-0.5.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/unexceptionalio-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/unexceptionalio-0.5.1
hs-libraries:         HSunexceptionalio-0.5.1-6IxKBTb3CJ2L1m1AvesDi3
depends:              base-4.14.2.0
haddock-interfaces:
    /usr/share/doc/haskell-unexceptionalio/html/unexceptionalio.haddock

haddock-html:         /usr/share/doc/haskell-unexceptionalio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unexceptionalio-0.5.1-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unexceptionalio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unexceptionalio
version:              0.5.1
visibility:           public
id:                   unexceptionalio-0.5.1-A2dsahXTN3YJSMAL6GdN1I
key:                  unexceptionalio-0.5.1-A2dsahXTN3YJSMAL6GdN1I
license:              LicenseRef-OtherLicense
copyright:            © 2013-2018 Stephen Paul Weber
maintainer:           Stephen Paul Weber <singpolyma@singpolyma.net>
author:               Stephen Paul Weber <singpolyma@singpolyma.net>
stability:            experimental
homepage:             https://github.com/singpolyma/unexceptionalio
synopsis:             IO without any non-error, synchronous exceptions
description:
    When you'\''ve caught all the exceptions that can be handled safely,
    this is what you'\''re left with.

    It is intended that you use qualified imports with this library.

    > import UnexceptionalIO (UIO)
    > import qualified UnexceptionalIO as UIO

    You may also wish to investigate unexceptionalio-trans if you like
    monad transformers.

    Blog post: http://sngpl.ma/p4uT0

category:             Control
abi:                  d495e9d5c76ad378269b7d3b8d084fb6
exposed:              True
exposed-modules:      UnexceptionalIO
import-dirs:          /usr/lib/ghc-9.0.1/site-local/unexceptionalio-0.5.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/unexceptionalio-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/unexceptionalio-0.5.1
hs-libraries:         HSunexceptionalio-0.5.1-A2dsahXTN3YJSMAL6GdN1I
depends:              base-4.15.0.0
haddock-interfaces:
    /usr/share/doc/haskell-unexceptionalio/html/unexceptionalio.haddock

haddock-html:         /usr/share/doc/haskell-unexceptionalio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
